searchData={"items":[{"type":"module","title":"Caddy","doc":"# Caddy\n\nStart Caddy HTTP Server in supervisor tree\n\n- Start in your application\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    # Start a Caddy by calling: Caddy.start_link([])\n    {Caddy, [\n      caddy_bin: \"/usr/bin/caddy\",\n    ]}\n    # Start the Telemetry supervisor\n    PhoenixWeb.Telemetry,\n    # Start the PubSub system\n    {Phoenix.PubSub, name: PhoenixWeb.PubSub},\n    # Start the Endpoint (http/https)\n    PhoenixWeb.Endpoint\n  ]\n\n  opts = [strategy: :one_for_one, name: PhoenixWeb.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```\n\n- Start in extra_applications\n\n```elixir\ndef application do\n  [\n    extra_applications: [Caddy.Application]\n  ]\nend\n```\n\n* Notice\n\nIf caddy_bin is not specifiy, Caddy.Server will not start.\nYou can set it latter by `Caddy.Config.set_bin(\"path/to/caddy\")` and restart server by `Caddy.restart_server()`","ref":"Caddy.html"},{"type":"function","title":"Caddy.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Caddy.html#child_spec/1"},{"type":"function","title":"Caddy.restart_server/0","doc":"Restart Caddy Server","ref":"Caddy.html#restart_server/0"},{"type":"function","title":"Caddy.start/0","doc":"","ref":"Caddy.html#start/0"},{"type":"function","title":"Caddy.start/1","doc":"","ref":"Caddy.html#start/1"},{"type":"function","title":"Caddy.start_link/1","doc":"","ref":"Caddy.html#start_link/1"},{"type":"function","title":"Caddy.stop/1","doc":"","ref":"Caddy.html#stop/1"},{"type":"module","title":"Caddy.Admin","doc":"Caddy Admin\n\nStart Caddy Admin","ref":"Caddy.Admin.html"},{"type":"function","title":"Caddy.Admin.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Caddy.Admin.html#child_spec/1"},{"type":"function","title":"Caddy.Admin.init/1","doc":"","ref":"Caddy.Admin.html#init/1"},{"type":"function","title":"Caddy.Admin.start_link/1","doc":"","ref":"Caddy.Admin.html#start_link/1"},{"type":"module","title":"Caddy.Admin.Api","doc":"Control Caddy Server through admin socket","ref":"Caddy.Admin.Api.html"},{"type":"module","title":"Admin API - Caddy.Admin.Api","doc":"```\nPOST /load Sets or replaces the active configuration\nPOST /stop Stops the active configuration and exits the process\nGET /config/[path] Exports the config at the named path\nPOST /config/[path] Sets or replaces object; appends to array\nPUT /config/[path] Creates new object; inserts into array\nPATCH /config/[path] Replaces an existing object or array element\nDELETE /config/[path] Deletes the value at the named path\nUsing @id in JSON Easily traverse into the config structure\nConcurrent config changes Avoid collisions when making unsynchronized changes to config\nPOST /adapt Adapts a configuration to JSON without running it\nGET /pki/ca/  Returns information about a particular PKI app CA\nGET /pki/ca/ /certificates Returns the certificate chain of a particular PKI app CA\nGET /reverse_proxy/upstreams Returns the current status of the configured proxy upstreams\n```","ref":"Caddy.Admin.Api.html#module-admin-api"},{"type":"function","title":"Caddy.Admin.Api.adapt/1","doc":"Adapts a configuration to JSON without running it","ref":"Caddy.Admin.Api.html#adapt/1"},{"type":"function","title":"Caddy.Admin.Api.delete_config/0","doc":"","ref":"Caddy.Admin.Api.html#delete_config/0"},{"type":"function","title":"Caddy.Admin.Api.delete_config/1","doc":"Delete the config at the named path","ref":"Caddy.Admin.Api.html#delete_config/1"},{"type":"function","title":"Caddy.Admin.Api.get/1","doc":"Get info from caddy server","ref":"Caddy.Admin.Api.html#get/1"},{"type":"function","title":"Caddy.Admin.Api.get_config/0","doc":"","ref":"Caddy.Admin.Api.html#get_config/0"},{"type":"function","title":"Caddy.Admin.Api.get_config/1","doc":"Exports the config at the named path","ref":"Caddy.Admin.Api.html#get_config/1"},{"type":"function","title":"Caddy.Admin.Api.load/1","doc":"Sets or replaces the active configuration","ref":"Caddy.Admin.Api.html#load/1"},{"type":"function","title":"Caddy.Admin.Api.patch_config/1","doc":"","ref":"Caddy.Admin.Api.html#patch_config/1"},{"type":"function","title":"Caddy.Admin.Api.patch_config/2","doc":"Patch the config at the named path","ref":"Caddy.Admin.Api.html#patch_config/2"},{"type":"function","title":"Caddy.Admin.Api.post_config/1","doc":"","ref":"Caddy.Admin.Api.html#post_config/1"},{"type":"function","title":"Caddy.Admin.Api.post_config/2","doc":"Post the config at the named path","ref":"Caddy.Admin.Api.html#post_config/2"},{"type":"function","title":"Caddy.Admin.Api.put_config/1","doc":"","ref":"Caddy.Admin.Api.html#put_config/1"},{"type":"function","title":"Caddy.Admin.Api.put_config/2","doc":"Put the config at the named path","ref":"Caddy.Admin.Api.html#put_config/2"},{"type":"function","title":"Caddy.Admin.Api.stop/0","doc":"Stops the active configuration and exits the process","ref":"Caddy.Admin.Api.html#stop/0"},{"type":"module","title":"Caddy.Admin.Request","doc":"Req, send request through socket","ref":"Caddy.Admin.Request.html"},{"type":"function","title":"Caddy.Admin.Request.delete/3","doc":"Send HTTP DELETE method to admin socket","ref":"Caddy.Admin.Request.html#delete/3"},{"type":"function","title":"Caddy.Admin.Request.get/1","doc":"Send HTTP GET method to admin socket","ref":"Caddy.Admin.Request.html#get/1"},{"type":"function","title":"Caddy.Admin.Request.patch/3","doc":"Send HTTP PATCH method to admin socket","ref":"Caddy.Admin.Request.html#patch/3"},{"type":"function","title":"Caddy.Admin.Request.post/3","doc":"Send HTTP POST method to admin socket","ref":"Caddy.Admin.Request.html#post/3"},{"type":"function","title":"Caddy.Admin.Request.put/3","doc":"Send HTTP PUT method to admin socket","ref":"Caddy.Admin.Request.html#put/3"},{"type":"type","title":"Caddy.Admin.Request.t/0","doc":"","ref":"Caddy.Admin.Request.html#t:t/0"},{"type":"module","title":"Caddy.Config","doc":"Caddy Config\n\nStart Caddy Config","ref":"Caddy.Config.html"},{"type":"function","title":"Caddy.Config.adapt/1","doc":"Convert caddyfile to json format.","ref":"Caddy.Config.html#adapt/1"},{"type":"type","title":"Caddy.Config.caddyfile/0","doc":"","ref":"Caddy.Config.html#t:caddyfile/0"},{"type":"function","title":"Caddy.Config.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Caddy.Config.html#child_spec/1"},{"type":"function","title":"Caddy.Config.env_file/0","doc":"","ref":"Caddy.Config.html#env_file/0"},{"type":"function","title":"Caddy.Config.etc_path/0","doc":"","ref":"Caddy.Config.html#etc_path/0"},{"type":"function","title":"Caddy.Config.get/1","doc":"Get the :key in Caddy Cofnig","ref":"Caddy.Config.html#get/1"},{"type":"function","title":"Caddy.Config.get_config/0","doc":"Return the current configuration in `Caddy.Config`","ref":"Caddy.Config.html#get_config/0"},{"type":"function","title":"Caddy.Config.init/1","doc":"","ref":"Caddy.Config.html#init/1"},{"type":"function","title":"Caddy.Config.init_file/0","doc":"","ref":"Caddy.Config.html#init_file/0"},{"type":"function","title":"Caddy.Config.pid_file/0","doc":"","ref":"Caddy.Config.html#pid_file/0"},{"type":"function","title":"Caddy.Config.priv_path/0","doc":"","ref":"Caddy.Config.html#priv_path/0"},{"type":"function","title":"Caddy.Config.run_path/0","doc":"","ref":"Caddy.Config.html#run_path/0"},{"type":"function","title":"Caddy.Config.saved/0","doc":"","ref":"Caddy.Config.html#saved/0"},{"type":"function","title":"Caddy.Config.saved_json_file/0","doc":"","ref":"Caddy.Config.html#saved_json_file/0"},{"type":"function","title":"Caddy.Config.set_bin/1","doc":"Set the Caddy binary path","ref":"Caddy.Config.html#set_bin/1"},{"type":"function","title":"Caddy.Config.set_bin!/1","doc":"Set the caddy binary path and restart Caddy.Server","ref":"Caddy.Config.html#set_bin!/1"},{"type":"function","title":"Caddy.Config.set_config/1","doc":"Replace the current configuration in `Caddy.Config`","ref":"Caddy.Config.html#set_config/1"},{"type":"function","title":"Caddy.Config.set_global/1","doc":"Set the global configuration\n\n```\nCaddy.Config.set_global(\"\"\"\ndebug\nauto_https off\n\"\"\")\n```","ref":"Caddy.Config.html#set_global/1"},{"type":"function","title":"Caddy.Config.set_site/2","doc":"Set the site configuration\n\n```\nCaddy.Config.set_site(\"www.gsmlg.com\", \"\"\"\nreverse_proxy {\n  to localhost:4000\n  header_up host www.gsmlg.com\n  header_up X-Real-IP {remote_host}\n}\n\"\"\")\n# or\nCaddy.Config.set_site(\"proxy\", {\":8080\", \"\"\"\nreverse_proxy {\n  to localhost:3128\n}\n\"\"\"})\n```","ref":"Caddy.Config.html#set_site/2"},{"type":"function","title":"Caddy.Config.share_path/0","doc":"","ref":"Caddy.Config.html#share_path/0"},{"type":"type","title":"Caddy.Config.site_config/0","doc":"","ref":"Caddy.Config.html#t:site_config/0"},{"type":"type","title":"Caddy.Config.site_listen/0","doc":"","ref":"Caddy.Config.html#t:site_listen/0"},{"type":"type","title":"Caddy.Config.site_name/0","doc":"","ref":"Caddy.Config.html#t:site_name/0"},{"type":"function","title":"Caddy.Config.socket_file/0","doc":"","ref":"Caddy.Config.html#socket_file/0"},{"type":"function","title":"Caddy.Config.start_link/1","doc":"","ref":"Caddy.Config.html#start_link/1"},{"type":"type","title":"Caddy.Config.t/0","doc":"","ref":"Caddy.Config.html#t:t/0"},{"type":"function","title":"Caddy.Config.tmp_path/0","doc":"","ref":"Caddy.Config.html#tmp_path/0"},{"type":"function","title":"Caddy.Config.to_caddyfile/1","doc":"Confirt `%Caddy.Config{}` to `caddyfile()`","ref":"Caddy.Config.html#to_caddyfile/1"},{"type":"function","title":"Caddy.Config.user_home/0","doc":"","ref":"Caddy.Config.html#user_home/0"},{"type":"function","title":"Caddy.Config.user_share/0","doc":"","ref":"Caddy.Config.html#user_share/0"},{"type":"function","title":"Caddy.Config.xdg_config_home/0","doc":"","ref":"Caddy.Config.html#xdg_config_home/0"},{"type":"function","title":"Caddy.Config.xdg_data_home/0","doc":"","ref":"Caddy.Config.html#xdg_data_home/0"},{"type":"module","title":"Caddy.Logger","doc":"Caddy Logger\n\nStart Caddy Logger","ref":"Caddy.Logger.html"},{"type":"function","title":"Caddy.Logger.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Caddy.Logger.html#child_spec/1"},{"type":"function","title":"Caddy.Logger.start_link/1","doc":"","ref":"Caddy.Logger.html#start_link/1"},{"type":"function","title":"Caddy.Logger.tail/1","doc":"","ref":"Caddy.Logger.html#tail/1"},{"type":"function","title":"Caddy.Logger.write/1","doc":"","ref":"Caddy.Logger.html#write/1"},{"type":"module","title":"Caddy.Server","doc":"Caddy Server\n\nStart Caddy Server","ref":"Caddy.Server.html"},{"type":"function","title":"Caddy.Server.bootstrap/0","doc":"","ref":"Caddy.Server.html#bootstrap/0"},{"type":"function","title":"Caddy.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Caddy.Server.html#child_spec/1"},{"type":"function","title":"Caddy.Server.get_caddyfile/0","doc":"","ref":"Caddy.Server.html#get_caddyfile/0"},{"type":"function","title":"Caddy.Server.handle_continue/2","doc":"","ref":"Caddy.Server.html#handle_continue/2"},{"type":"function","title":"Caddy.Server.init/1","doc":"","ref":"Caddy.Server.html#init/1"},{"type":"function","title":"Caddy.Server.start_link/1","doc":"","ref":"Caddy.Server.html#start_link/1"},{"type":"function","title":"Caddy.Server.stop/0","doc":"","ref":"Caddy.Server.html#stop/0"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.0"}}